You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@ant.apache.org by bo...@apache.org on 2017/12/10 07:58:53 UTC

[08/11] ant git commit: Let’s use doclint

Let’s use doclint

Project: http://git-wip-us.apache.org/repos/asf/ant/repo
Commit: http://git-wip-us.apache.org/repos/asf/ant/commit/67f29ce0
Tree: http://git-wip-us.apache.org/repos/asf/ant/tree/67f29ce0
Diff: http://git-wip-us.apache.org/repos/asf/ant/diff/67f29ce0

Branch: refs/heads/master
Commit: 67f29ce0c2ad332570c0a1382c79532cee66dce8
Parents: 608b65a
Author: Gintas Grigelionis <gi...@apache.org>
Authored: Sun Dec 10 07:12:42 2017 +0100
Committer: Gintas Grigelionis <gi...@apache.org>
Committed: Sun Dec 10 07:12:42 2017 +0100

----------------------------------------------------------------------
 build.xml                                       |  11 +-
 .../org/apache/tools/ant/AntClassLoader.java    |  10 +-
 .../org/apache/tools/ant/ArgumentProcessor.java |  16 +++
 .../org/apache/tools/ant/ComponentHelper.java   |   4 +-
 src/main/org/apache/tools/ant/Diagnostics.java  |  10 +-
 .../org/apache/tools/ant/DirectoryScanner.java  |  35 +++--
 .../apache/tools/ant/IntrospectionHelper.java   |   4 +-
 src/main/org/apache/tools/ant/MagicNames.java   |   4 +-
 src/main/org/apache/tools/ant/Main.java         |   3 -
 src/main/org/apache/tools/ant/Project.java      |  33 ++---
 .../org/apache/tools/ant/ProjectComponent.java  |   2 +-
 .../org/apache/tools/ant/ProjectHelper.java     |  14 +-
 .../tools/ant/ProjectHelperRepository.java      |   4 +-
 .../org/apache/tools/ant/PropertyHelper.java    |  13 +-
 .../apache/tools/ant/RuntimeConfigurable.java   |  23 ++--
 src/main/org/apache/tools/ant/Target.java       |   2 +
 src/main/org/apache/tools/ant/TaskAdapter.java  |   2 +-
 .../tools/ant/TaskConfigurationChecker.java     |   2 +-
 .../apache/tools/ant/dispatch/DispatchTask.java |   3 +-
 .../ant/filters/BaseParamFilterReader.java      |   2 +-
 .../tools/ant/filters/ClassConstants.java       |   5 +-
 .../tools/ant/filters/ExpandProperties.java     |   3 +-
 .../apache/tools/ant/filters/FixCrLfFilter.java |  25 ++--
 .../tools/ant/filters/LineContainsRegExp.java   |   4 +-
 .../apache/tools/ant/filters/ReplaceTokens.java |   1 +
 .../apache/tools/ant/filters/SortFilter.java    |  14 +-
 .../apache/tools/ant/helper/AntXMLContext.java  |  11 +-
 .../apache/tools/ant/helper/ProjectHelper2.java |  16 +--
 .../tools/ant/helper/ProjectHelperImpl.java     |   4 +-
 .../tools/ant/helper/SingleCheckExecutor.java   |   2 -
 .../org/apache/tools/ant/launch/Launcher.java   |   5 +-
 .../org/apache/tools/ant/launch/Locator.java    |   4 +-
 .../tools/ant/listener/AnsiColorLogger.java     |   2 +-
 .../tools/ant/listener/BigProjectLogger.java    |   8 +-
 .../ant/listener/CommonsLoggingListener.java    |  10 +-
 .../tools/ant/listener/Log4jListener.java       |  13 +-
 .../apache/tools/ant/listener/MailLogger.java   |   2 -
 .../tools/ant/taskdefs/AbstractCvsTask.java     |  19 ++-
 .../ant/taskdefs/AbstractJarSignerTask.java     |   4 +-
 src/main/org/apache/tools/ant/taskdefs/Ant.java |   5 +-
 .../ant/taskdefs/AttributeNamespaceDef.java     |   2 +-
 .../apache/tools/ant/taskdefs/Available.java    |   2 +-
 .../apache/tools/ant/taskdefs/BuildNumber.java  |   2 +-
 .../org/apache/tools/ant/taskdefs/Concat.java   |   3 +-
 .../org/apache/tools/ant/taskdefs/Copy.java     |   6 +-
 .../org/apache/tools/ant/taskdefs/Delete.java   |  26 +++-
 .../apache/tools/ant/taskdefs/DependSet.java    |   1 +
 .../org/apache/tools/ant/taskdefs/Echo.java     |   1 +
 .../org/apache/tools/ant/taskdefs/EchoXML.java  |   3 +-
 .../org/apache/tools/ant/taskdefs/ExecTask.java |   2 +
 .../org/apache/tools/ant/taskdefs/Execute.java  |   4 +-
 .../org/apache/tools/ant/taskdefs/Expand.java   |   9 ++
 .../org/apache/tools/ant/taskdefs/FixCRLF.java  |   2 +-
 src/main/org/apache/tools/ant/taskdefs/Get.java |   9 +-
 .../apache/tools/ant/taskdefs/ImportTask.java   |   7 +
 .../org/apache/tools/ant/taskdefs/JDBCTask.java |   4 +-
 src/main/org/apache/tools/ant/taskdefs/Jar.java |   5 +-
 .../org/apache/tools/ant/taskdefs/Javac.java    |   4 +
 .../org/apache/tools/ant/taskdefs/Javadoc.java  |  12 +-
 .../tools/ant/taskdefs/LoadProperties.java      |   1 +
 .../tools/ant/taskdefs/LogOutputStream.java     |   2 +-
 .../org/apache/tools/ant/taskdefs/MakeUrl.java  |   2 +-
 .../org/apache/tools/ant/taskdefs/Manifest.java |   4 +-
 .../apache/tools/ant/taskdefs/ManifestTask.java |   2 +
 .../apache/tools/ant/taskdefs/MatchingTask.java |   2 +-
 .../org/apache/tools/ant/taskdefs/Move.java     |   9 +-
 .../org/apache/tools/ant/taskdefs/Pack.java     |   2 +-
 .../org/apache/tools/ant/taskdefs/Property.java |   6 +-
 .../tools/ant/taskdefs/PumpStreamHandler.java   |   1 +
 .../org/apache/tools/ant/taskdefs/Recorder.java |   3 +-
 .../tools/ant/taskdefs/RecorderEntry.java       |  27 ++--
 .../apache/tools/ant/taskdefs/Redirector.java   |   2 +
 .../org/apache/tools/ant/taskdefs/Replace.java  |  12 +-
 .../org/apache/tools/ant/taskdefs/Rmic.java     |  10 +-
 .../org/apache/tools/ant/taskdefs/SQLExec.java  |  13 ++
 .../apache/tools/ant/taskdefs/Sequential.java   |   3 +-
 .../org/apache/tools/ant/taskdefs/SignJar.java  |   8 +-
 .../org/apache/tools/ant/taskdefs/SubAnt.java   |  18 ++-
 .../org/apache/tools/ant/taskdefs/Sync.java     |   8 +-
 .../org/apache/tools/ant/taskdefs/TempFile.java |   2 +-
 .../org/apache/tools/ant/taskdefs/Tstamp.java   |   2 +
 .../org/apache/tools/ant/taskdefs/Untar.java    |   5 +-
 .../org/apache/tools/ant/taskdefs/WaitFor.java  |   2 +-
 .../apache/tools/ant/taskdefs/XSLTLiaison.java  |   2 +-
 .../apache/tools/ant/taskdefs/XSLTLiaison2.java |   2 +-
 .../apache/tools/ant/taskdefs/XSLTProcess.java  |  41 +++++-
 .../apache/tools/ant/taskdefs/XmlProperty.java  |   8 +-
 src/main/org/apache/tools/ant/taskdefs/Zip.java |  22 +++-
 .../compilers/DefaultCompilerAdapter.java       |   2 +-
 .../ant/taskdefs/compilers/JavacExternal.java   |   6 +-
 .../tools/ant/taskdefs/condition/Http.java      |   4 +-
 .../ant/taskdefs/condition/IsLastModified.java  |   4 +-
 .../ant/taskdefs/condition/IsReachable.java     |   2 +-
 .../apache/tools/ant/taskdefs/condition/Os.java |   8 +-
 .../ant/taskdefs/condition/ResourceExists.java  |   2 +
 .../ant/taskdefs/cvslib/ChangeLogTask.java      |  49 +++----
 .../tools/ant/taskdefs/cvslib/CvsTagDiff.java   |  16 +--
 .../tools/ant/taskdefs/email/EmailAddress.java  |   6 +-
 .../tools/ant/taskdefs/email/EmailTask.java     |   5 +
 .../apache/tools/ant/taskdefs/email/Mailer.java |  11 +-
 .../ant/taskdefs/launcher/CommandLauncher.java  |  12 ++
 .../tools/ant/taskdefs/optional/ANTLR.java      |   2 +-
 .../ant/taskdefs/optional/EchoProperties.java   | 129 ++++++++++---------
 .../tools/ant/taskdefs/optional/Javah.java      |   3 +
 .../ant/taskdefs/optional/Native2Ascii.java     |  10 +-
 .../tools/ant/taskdefs/optional/NetRexxC.java   |   8 +-
 .../ant/taskdefs/optional/PropertyFile.java     |  31 +++--
 .../ant/taskdefs/optional/ReplaceRegExp.java    |  24 ++--
 .../apache/tools/ant/taskdefs/optional/Rpm.java |   2 +-
 .../ant/taskdefs/optional/SchemaValidate.java   |   4 +-
 .../tools/ant/taskdefs/optional/Script.java     |   2 +-
 .../ant/taskdefs/optional/TraXLiaison.java      |   1 -
 .../ant/taskdefs/optional/XMLValidateTask.java  |   6 +-
 .../taskdefs/optional/ccm/CCMCreateTask.java    |  14 +-
 .../taskdefs/optional/ccm/CCMReconfigure.java   |   4 +-
 .../taskdefs/optional/clearcase/CCCheckin.java  |   1 +
 .../taskdefs/optional/clearcase/CCCheckout.java |   1 +
 .../ant/taskdefs/optional/clearcase/CCLock.java |   1 +
 .../taskdefs/optional/clearcase/CCMkattr.java   |   1 +
 .../ant/taskdefs/optional/clearcase/CCMkbl.java |   1 +
 .../taskdefs/optional/clearcase/CCMkdir.java    |   1 +
 .../taskdefs/optional/clearcase/CCMkelem.java   |   1 +
 .../taskdefs/optional/clearcase/CCMklabel.java  |   1 +
 .../taskdefs/optional/clearcase/CCMklbtype.java |   1 +
 .../taskdefs/optional/clearcase/CCRmtype.java   |   3 +-
 .../optional/clearcase/CCUnCheckout.java        |   1 +
 .../taskdefs/optional/clearcase/CCUnlock.java   |   1 +
 .../taskdefs/optional/clearcase/CCUpdate.java   |   1 +
 .../ant/taskdefs/optional/depend/Depend.java    |   2 +-
 .../depend/constantpool/MethodHandleCPInfo.java |   2 +-
 .../optional/ejb/DescriptorHandler.java         |   2 +-
 .../tools/ant/taskdefs/optional/ejb/EjbJar.java |   8 +-
 .../optional/ejb/GenericDeploymentTool.java     |   6 +-
 .../optional/ejb/IPlanetDeploymentTool.java     |  12 +-
 .../ant/taskdefs/optional/ejb/IPlanetEjbc.java  |  34 ++---
 .../optional/ejb/JbossDeploymentTool.java       |   1 -
 .../optional/ejb/OrionDeploymentTool.java       |   7 +-
 .../optional/ejb/WebsphereDeploymentTool.java   |   8 +-
 .../optional/extension/Compatability.java       |   2 +-
 .../optional/extension/Compatibility.java       |   2 +-
 .../optional/extension/ExtensionUtil.java       |   6 +-
 .../optional/extension/JarLibAvailableTask.java |   2 +-
 .../optional/extension/JarLibDisplayTask.java   |   2 +-
 .../optional/extension/JarLibManifestTask.java  |   4 +-
 .../optional/extension/JarLibResolveTask.java   |   2 +-
 .../taskdefs/optional/extension/LibFileSet.java |   2 +-
 .../optional/extension/LibraryDisplayer.java    |   2 +-
 .../optional/extension/Specification.java       |   6 +-
 .../ant/taskdefs/optional/i18n/Translate.java   |   6 +-
 .../ant/taskdefs/optional/image/Image.java      |   5 +
 .../j2ee/AbstractHotDeploymentTool.java         |  10 +-
 .../optional/j2ee/JonasHotDeploymentTool.java   |  14 +-
 .../j2ee/WebLogicHotDeploymentTool.java         |  27 ++--
 .../ant/taskdefs/optional/javacc/JJTree.java    |   8 +-
 .../taskdefs/optional/jdepend/JDependTask.java  |   2 +-
 .../ant/taskdefs/optional/jlink/JlinkTask.java  |   4 +-
 .../tools/ant/taskdefs/optional/jsp/JspC.java   |  18 +--
 .../compilers/DefaultJspCompilerAdapter.java    |   2 +-
 .../jsp/compilers/JspCompilerAdapter.java       |   2 +-
 .../ant/taskdefs/optional/junit/BaseTest.java   |   2 +
 .../ant/taskdefs/optional/junit/BatchTest.java  |   8 +-
 .../junit/BriefJUnitResultFormatter.java        |   4 +-
 .../optional/junit/FailureRecorder.java         |   8 +-
 .../optional/junit/FormatterElement.java        |  54 ++++----
 .../optional/junit/IgnoredTestListener.java     |   6 +-
 .../ant/taskdefs/optional/junit/JUnitTask.java  |  74 ++++++-----
 .../ant/taskdefs/optional/junit/JUnitTest.java  |   6 +-
 .../optional/junit/JUnitTestRunner.java         |  77 ++++++-----
 .../junit/PlainJUnitResultFormatter.java        |   2 +-
 .../taskdefs/optional/junit/XMLConstants.java   |  10 +-
 .../optional/junit/XMLJUnitResultFormatter.java |   4 +-
 .../optional/junit/XMLResultAggregator.java     |  17 +--
 .../native2ascii/DefaultNative2Ascii.java       |   2 +-
 .../tools/ant/taskdefs/optional/net/FTP.java    |  21 +--
 .../ant/taskdefs/optional/net/FTPTask.java      |   1 +
 .../optional/net/FTPTaskMirrorImpl.java         |  10 +-
 .../tools/ant/taskdefs/optional/pvcs/Pvcs.java  |   4 +-
 .../tools/ant/taskdefs/optional/sos/SOS.java    |   8 +-
 .../ant/taskdefs/optional/sos/SOSCheckin.java   |   7 +-
 .../ant/taskdefs/optional/sos/SOSCheckout.java  |   7 +-
 .../tools/ant/taskdefs/optional/sos/SOSGet.java |   7 +-
 .../ant/taskdefs/optional/sos/SOSLabel.java     |   8 +-
 .../ant/taskdefs/optional/sos/package.html      |   8 +-
 .../optional/ssh/AbstractSshMessage.java        |   5 +-
 .../ant/taskdefs/optional/ssh/SSHBase.java      |   6 +-
 .../ant/taskdefs/optional/ssh/SSHExec.java      |  12 +-
 .../ant/taskdefs/optional/ssh/SSHSession.java   |   5 +-
 .../tools/ant/taskdefs/optional/ssh/Scp.java    |  27 ++--
 .../ant/taskdefs/optional/ssh/ScpToMessage.java |   5 +
 .../optional/ssh/ScpToMessageBySftp.java        |   2 +-
 .../ant/taskdefs/optional/testing/Funtest.java  |  19 +--
 .../optional/unix/AbstractAccessTask.java       |   4 +-
 .../tools/ant/taskdefs/optional/unix/Chgrp.java |   4 +-
 .../tools/ant/taskdefs/optional/unix/Chown.java |   4 +-
 .../ant/taskdefs/optional/unix/Symlink.java     |  36 +++---
 .../tools/ant/taskdefs/optional/vss/MSVSS.java  |  11 +-
 .../ant/taskdefs/optional/vss/MSVSSADD.java     |   2 +-
 .../taskdefs/optional/vss/MSVSSCHECKOUT.java    |   2 +-
 .../ant/taskdefs/optional/vss/MSVSSCP.java      |   2 +-
 .../ant/taskdefs/optional/vss/MSVSSCREATE.java  |   2 +-
 .../ant/taskdefs/optional/vss/MSVSSGET.java     |   2 +-
 .../ant/taskdefs/optional/vss/MSVSSHISTORY.java |   2 +-
 .../ant/taskdefs/optional/vss/MSVSSLABEL.java   |   2 +-
 .../apache/tools/ant/types/AbstractFileSet.java |   4 +
 .../org/apache/tools/ant/types/Assertions.java  |   6 +-
 .../org/apache/tools/ant/types/Commandline.java |  38 +++---
 .../apache/tools/ant/types/CommandlineJava.java |   2 +-
 .../org/apache/tools/ant/types/DataType.java    |   4 +-
 .../tools/ant/types/EnumeratedAttribute.java    |   2 +-
 .../org/apache/tools/ant/types/FileList.java    |   2 +-
 src/main/org/apache/tools/ant/types/Path.java   |  32 ++---
 .../org/apache/tools/ant/types/Quantifier.java  |  24 ++--
 .../tools/ant/types/RedirectorElement.java      |   1 +
 .../org/apache/tools/ant/types/Resource.java    |   6 +-
 .../tools/ant/types/ResourceLocation.java       |   5 +-
 .../apache/tools/ant/types/Substitution.java    |   1 -
 .../org/apache/tools/ant/types/XMLCatalog.java  |  32 +++--
 .../tools/ant/types/mappers/CutDirsMapper.java  |   1 +
 .../types/optional/AbstractScriptComponent.java |   2 +-
 .../tools/ant/types/optional/ScriptFilter.java  |   4 +-
 .../tools/ant/types/optional/ScriptMapper.java  |   2 +-
 .../ant/types/optional/ScriptSelector.java      |   4 +-
 .../types/optional/depend/DependScanner.java    |  14 +-
 .../ant/types/optional/image/DrawOperation.java |   2 +-
 .../tools/ant/types/optional/image/Ellipse.java |   2 +-
 .../tools/ant/types/optional/image/Rotate.java  |   6 +-
 .../tools/ant/types/resolver/ApacheCatalog.java |   4 +-
 .../types/resolver/ApacheCatalogResolver.java   |   4 +-
 .../resources/AbstractClasspathResource.java    |  13 +-
 .../ant/types/resources/ArchiveResource.java    |   2 +-
 .../tools/ant/types/resources/Archives.java     |  17 +++
 .../BaseResourceCollectionContainer.java        |   1 +
 .../resources/ContentTransformingResource.java  |   6 +-
 .../LazyResourceCollectionWrapper.java          |   2 +-
 .../ant/types/resources/LogOutputResource.java  |   2 +-
 .../resources/MappedResourceCollection.java     |   1 +
 .../ant/types/resources/ResourceDecorator.java  |   1 +
 .../tools/ant/types/resources/ResourceList.java |  19 ++-
 .../tools/ant/types/resources/Resources.java    |   1 +
 .../types/resources/SizeLimitCollection.java    |   6 +-
 .../tools/ant/types/resources/URLResource.java  |   2 +
 .../apache/tools/ant/types/resources/Union.java |   5 +-
 .../tools/ant/types/resources/ZipResource.java  |   1 +
 .../types/resources/comparators/Content.java    |   2 +-
 .../ant/types/resources/selectors/Name.java     |   2 +-
 .../selectors/ResourceSelectorContainer.java    |   8 +-
 .../tools/ant/types/selectors/BaseSelector.java |   1 +
 .../tools/ant/types/selectors/DateSelector.java |   1 -
 .../ant/types/selectors/DifferentSelector.java  |   5 +-
 .../ant/types/selectors/PresentSelector.java    |   2 +-
 .../tools/ant/types/selectors/SizeSelector.java |   4 +-
 .../ant/types/selectors/TokenizedPath.java      |   8 +-
 .../ant/types/selectors/TokenizedPattern.java   |  17 +++
 .../modifiedselector/ChecksumAlgorithm.java     |  13 +-
 .../modifiedselector/DigestAlgorithm.java       |  21 +--
 .../modifiedselector/HashvalueAlgorithm.java    |   2 +-
 .../modifiedselector/ModifiedSelector.java      |  45 +++----
 .../modifiedselector/PropertiesfileCache.java   |  13 +-
 .../apache/tools/ant/util/ClasspathUtils.java   |  22 ++--
 .../ant/util/ConcatResourceInputStream.java     |   2 +-
 .../apache/tools/ant/util/DOMElementWriter.java |   5 +-
 .../org/apache/tools/ant/util/DateUtils.java    |  23 +++-
 .../org/apache/tools/ant/util/FileUtils.java    |  28 ++--
 .../tools/ant/util/GlobPatternMapper.java       |   1 +
 .../apache/tools/ant/util/IdentityStack.java    |   1 +
 .../org/apache/tools/ant/util/JavaEnvUtils.java |  11 +-
 .../tools/ant/util/KeepAliveInputStream.java    |   1 +
 .../tools/ant/util/KeepAliveOutputStream.java   |   3 +
 .../ant/util/LayoutPreservingProperties.java    |  13 +-
 .../apache/tools/ant/util/MergingMapper.java    |   1 +
 .../org/apache/tools/ant/util/ProcessUtil.java  |   2 +-
 .../org/apache/tools/ant/util/ReflectUtil.java  |   5 +
 .../apache/tools/ant/util/ScriptRunnerBase.java |   2 +-
 .../tools/ant/util/ScriptRunnerCreator.java     |   2 +-
 .../tools/ant/util/ScriptRunnerHelper.java      |   2 +-
 .../apache/tools/ant/util/SplitClassLoader.java |   5 +-
 .../tools/ant/util/SymbolicLinkUtils.java       |   6 +-
 .../apache/tools/ant/util/TimeoutObserver.java  |   2 +-
 .../org/apache/tools/ant/util/UUEncoder.java    |   5 +-
 .../org/apache/tools/ant/util/UnicodeUtil.java  |   2 +-
 .../apache/tools/ant/util/WeakishReference.java |   2 +-
 .../org/apache/tools/ant/util/WorkerAnt.java    |   4 +-
 .../tools/ant/util/depend/AbstractAnalyzer.java |   2 +-
 .../tools/ant/util/regexp/JakartaOroRegexp.java |   2 +-
 .../ant/util/regexp/JakartaRegexpRegexp.java    |   2 +-
 .../ant/util/regexp/Jdk14RegexpRegexp.java      |   2 +-
 .../ant/util/regexp/RegexpMatcherFactory.java   |   2 +-
 .../tools/ant/util/regexp/RegexpUtil.java       |   8 +-
 src/main/org/apache/tools/bzip2/BlockSort.java  |   3 +-
 .../apache/tools/bzip2/CBZip2InputStream.java   |   8 +-
 .../apache/tools/bzip2/CBZip2OutputStream.java  |  46 +++----
 src/main/org/apache/tools/mail/MailMessage.java |  16 ++-
 .../apache/tools/mail/SmtpResponseReader.java   |   4 +-
 src/main/org/apache/tools/tar/TarEntry.java     |  36 +++---
 .../org/apache/tools/tar/TarInputStream.java    |   7 +-
 .../org/apache/tools/tar/TarOutputStream.java   |  14 +-
 src/main/org/apache/tools/tar/TarUtils.java     |   2 +
 .../tools/zip/AbstractUnicodeExtraField.java    |   2 +-
 .../org/apache/tools/zip/AsiExtraField.java     |   4 +-
 .../org/apache/tools/zip/ExtraFieldUtils.java   |   2 +
 .../apache/tools/zip/FallbackZipEncoding.java   |  11 +-
 .../org/apache/tools/zip/GeneralPurposeBit.java |  22 +++-
 .../org/apache/tools/zip/NioZipEncoding.java    |   9 +-
 .../apache/tools/zip/Simple8BitZipEncoding.java |   9 +-
 .../tools/zip/UnicodeCommentExtraField.java     |   5 +-
 .../apache/tools/zip/UnicodePathExtraField.java |   7 +-
 .../tools/zip/UnparseableExtraFieldData.java    |   4 +-
 .../zip/UnsupportedZipFeatureException.java     |   4 +
 .../zip/Zip64ExtendedInformationExtraField.java |  30 ++++-
 src/main/org/apache/tools/zip/ZipEncoding.java  |   4 +-
 src/main/org/apache/tools/zip/ZipEntry.java     |  48 ++++++-
 src/main/org/apache/tools/zip/ZipFile.java      |   9 +-
 .../org/apache/tools/zip/ZipOutputStream.java   |  82 +++++++++++-
 src/main/org/apache/tools/zip/ZipUtil.java      |  18 +++
 .../core/uuencode/src/task/BaseTask.java        |   1 +
 .../org/apache/tools/ant/BuildFileRule.java     |   7 +-
 .../org/apache/tools/ant/BuildFileTest.java     |  59 ++++++---
 .../org/apache/tools/ant/ImmutableTest.java     |   1 +
 .../apache/tools/ant/PropertyExpansionTest.java |   3 +-
 .../org/apache/tools/ant/taskdefs/AntTest.java  |   1 -
 .../apache/tools/ant/taskdefs/DeleteTest.java   |   2 +-
 .../apache/tools/ant/taskdefs/MacroDefTest.java |   7 +
 .../ant/taskdefs/ManifestClassPathTest.java     |   1 -
 .../apache/tools/ant/taskdefs/ParallelTest.java |   4 +-
 .../apache/tools/ant/taskdefs/RenameTest.java   |   1 +
 .../tools/ant/taskdefs/RmicAdvancedTest.java    |   5 -
 .../apache/tools/ant/taskdefs/SQLExecTest.java  |  11 +-
 .../ant/taskdefs/condition/TypeFoundTest.java   |   1 -
 .../optional/AbstractXSLTLiaisonTest.java       |  14 +-
 .../ant/taskdefs/optional/TraXLiaisonTest.java  |   4 +-
 .../ant/taskdefs/optional/XmlValidateTest.java  |   1 -
 .../tools/ant/taskdefs/optional/XsltTest.java   |   1 -
 .../tools/ant/types/AbstractFileSetTest.java    |   1 -
 .../tools/ant/types/CommandlineJavaTest.java    |   1 -
 .../apache/tools/ant/types/CommandlineTest.java |   3 +-
 .../org/apache/tools/ant/types/DirSetTest.java  |   4 +-
 .../ant/types/EnumeratedAttributeTest.java      |   1 -
 .../org/apache/tools/ant/types/FileSetTest.java |   6 +-
 .../apache/tools/ant/types/FlexIntegerTest.java |   2 +-
 .../apache/tools/ant/types/PatternSetTest.java  |   3 +-
 .../apache/tools/ant/types/PermissionsTest.java |   3 +-
 .../apache/tools/ant/types/TarFileSetTest.java  |   7 +-
 .../apache/tools/ant/types/XMLCatalogTest.java  |   5 +-
 .../apache/tools/ant/types/ZipFileSetTest.java  |   5 +-
 .../tools/ant/types/mappers/GlobMapperTest.java |   2 +
 .../types/resources/MultiRootFileSetTest.java   |   1 -
 .../ant/types/selectors/BaseSelectorRule.java   |   8 ++
 .../ant/types/selectors/BaseSelectorTest.java   |  29 +++--
 .../types/selectors/ContainsSelectorTest.java   |   4 -
 .../types/selectors/ModifiedSelectorTest.java   |  57 +-------
 .../ant/types/selectors/SizeSelectorTest.java   |   1 +
 .../apache/tools/ant/util/DeweyDecimalTest.java |   3 +-
 .../util/LayoutPreservingPropertiesTest.java    |   2 +-
 .../ant/util/LineOrientedOutputStreamTest.java  |   2 +
 .../ant/util/regexp/JakartaOroMatcherTest.java  |   4 -
 .../ant/util/regexp/JakartaOroRegexpTest.java   |   4 -
 .../util/regexp/JakartaRegexpMatcherTest.java   |  15 +--
 .../util/regexp/JakartaRegexpRegexpTest.java    |  14 +-
 .../ant/util/regexp/Jdk14RegexpMatcherTest.java |  20 +--
 .../ant/util/regexp/Jdk14RegexpRegexpTest.java  |  20 +--
 .../ant/util/regexp/RegexpMatcherTest.java      |  32 +++--
 .../tools/ant/util/regexp/RegexpTest.java       |  12 +-
 .../org/apache/tools/mail/MailMessageTest.java  |   6 -
 .../apache/tools/zip/ExtraFieldUtilsTest.java   |   3 +-
 .../org/apache/tools/zip/ZipEntryTest.java      |   3 +-
 .../org/apache/tools/zip/ZipShortTest.java      |   3 +-
 366 files changed, 1915 insertions(+), 1276 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/build.xml
----------------------------------------------------------------------
diff --git a/build.xml b/build.xml
index ffa86f1..b14be72 100644
--- a/build.xml
+++ b/build.xml
@@ -1435,16 +1435,15 @@
     description="--> creates the API documentation" unless="javadoc.notrequired">
     <mkdir dir="${build.javadocs}"/>
     <javadoc useexternalfile="yes"
-      maxmemory="1000M" 
       destdir="${build.javadocs}"
+      failonerror="true"
       author="true"
       version="true"
       locale="en"
       windowtitle="${Name} API"
       doctitle="${Name}"
-      failonerror="true"
-      verbose="${javadoc.verbose}"
-      additionalparam="${javadoc.doclint.none}">
+      maxmemory="1000M"
+      verbose="${javadoc.verbose}">
 
       <packageset dir="${java.dir}"/>
 
@@ -1476,8 +1475,7 @@
       version="true"
       locale="en"
       windowtitle="${Name} Test Utilities"
-      doctitle="${Name}"
-      additionalparam="${javadoc.doclint.none}">
+      doctitle="${Name}">
 
       <!-- hide some meta information for javadoc -->
       <tag name="pre" description="Precondition:" scope="all"/>
@@ -1634,6 +1632,7 @@ ${antunit.reports}
                fork="${junit.fork}"
                forkmode="${junit.forkmode}"
                threads="${junit.threads}"
+               tempdir="${build.dir}"
                failureproperty="junit.failed"
                errorproperty="junit.failed"
                filtertrace="${junit.filtertrace}">

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/AntClassLoader.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/AntClassLoader.java b/src/main/org/apache/tools/ant/AntClassLoader.java
index 9fa9eae..9f22011 100644
--- a/src/main/org/apache/tools/ant/AntClassLoader.java
+++ b/src/main/org/apache/tools/ant/AntClassLoader.java
@@ -928,8 +928,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      *
      * @param name name of the resource
      * @return possible URLs as enumeration
-     * @throws IOException
-     * @see {@link #findResources(String, boolean)}
+     * @throws IOException if something goes wrong
+     * @see #findResources(String, boolean)
      * @since Ant 1.8.0
      */
     public Enumeration<URL> getNamedResources(final String name)
@@ -1561,6 +1561,12 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
 
     /**
      * Factory method
+     *
+     * @param parent ClassLoader
+     * @param project Project
+     * @param path Path
+     * @param parentFirst boolean
+     * @return AntClassLoader
      */
     public static AntClassLoader newAntClassLoader(final ClassLoader parent,
                                                    final Project project,

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/ArgumentProcessor.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/ArgumentProcessor.java b/src/main/org/apache/tools/ant/ArgumentProcessor.java
index 07812f2..7a547fd 100644
--- a/src/main/org/apache/tools/ant/ArgumentProcessor.java
+++ b/src/main/org/apache/tools/ant/ArgumentProcessor.java
@@ -37,6 +37,11 @@ public interface ArgumentProcessor {
      * <p>
      * If the argument is not supported, returns -1. Else, the position of the
      * first argument not supported.
+     * </p>
+     *
+     * @param args String[]
+     * @param pos int
+     * @return int
      */
     int readArguments(String[] args, int pos);
 
@@ -45,12 +50,18 @@ public interface ArgumentProcessor {
      * this method is called after all arguments were parsed. Returns
      * <code>true</code> if Ant should stop there, ie the build file not parsed
      * and the project should not be executed.
+     *
+     * @param args List&lt;String&gt;
+     * @return boolean
      */
     boolean handleArg(List<String> args);
 
     /**
      * If some arguments matched with {@link #readArguments(String[], int)},
      * this method is called just before the project being configured
+     *
+     * @param project Project
+     * @param args List&lt;String&gt;
      */
     void prepareConfigure(Project project, List<String> args);
 
@@ -59,12 +70,17 @@ public interface ArgumentProcessor {
      * after the project being configured. Returns <code>true</code> if Ant
      * should stop there, ie the build file not parsed and the project should
      * not be executed.
+     *
+     * @param project Project
+     * @param arg List&lt;String&gt;
+     * @return boolean
      */
     boolean handleArg(Project project, List<String> arg);
 
     /**
      * Print the usage of the supported arguments
      *
+     * @param writer PrintStream
      * @see org.apache.tools.ant.Main#printUsage()
      */
     void printUsage(PrintStream writer);

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/ComponentHelper.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/ComponentHelper.java b/src/main/org/apache/tools/ant/ComponentHelper.java
index 4942d24..9d0af85 100644
--- a/src/main/org/apache/tools/ant/ComponentHelper.java
+++ b/src/main/org/apache/tools/ant/ComponentHelper.java
@@ -53,7 +53,7 @@ import org.apache.tools.ant.util.FileUtils;
  *
  * A very simple hook mechanism is provided that allows users to plug
  * in custom code. It is also possible to replace the default behavior
- * ( for example in an app embedding ant )
+ * (for example in an app embedding Ant)
  *
  * @since Ant1.6
  */
@@ -202,7 +202,7 @@ public class ComponentHelper  {
     }
 
     /**
-     * @return A deep copy of the restrictredDefinition
+     * @return A deep copy of the restrictedDefinition
      */
     private Map<String, List<AntTypeDefinition>> getRestrictedDefinition() {
         final Map<String, List<AntTypeDefinition>> result = new HashMap<String, List<AntTypeDefinition>>();

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/Diagnostics.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/Diagnostics.java b/src/main/org/apache/tools/ant/Diagnostics.java
index e4a243b..74e1182 100644
--- a/src/main/org/apache/tools/ant/Diagnostics.java
+++ b/src/main/org/apache/tools/ant/Diagnostics.java
@@ -284,7 +284,7 @@ public final class Diagnostics {
     /**
      * ignore exceptions. This is to allow future
      * implementations to log at a verbose level
-     * @param thrown
+     * @param thrown a Throwable to ignore
      */
     private static void ignoreThrowable(Throwable thrown) {
     }
@@ -380,7 +380,7 @@ public final class Diagnostics {
     /**
      * Get the value of a system property. If a security manager
      * blocks access to a property it fills the result in with an error
-     * @param key
+     * @param key a property key
      * @return the system property's value or error text
      * @see #ERROR_PROPERTY_ACCESS_BLOCKED
      */
@@ -526,7 +526,7 @@ public final class Diagnostics {
 
     /**
      * tell the user about the XML parser
-     * @param out
+     * @param out a PrintStream
      */
     private static void doReportParserInfo(PrintStream out) {
         String parserName = getXMLParserName();
@@ -538,7 +538,7 @@ public final class Diagnostics {
 
     /**
      * tell the user about the XSLT processor
-     * @param out
+     * @param out a PrintStream
      */
     private static void doReportXSLTProcessorInfo(PrintStream out) {
         String processorName = getXSLTProcessorName();
@@ -562,7 +562,7 @@ public final class Diagnostics {
      * try and create a temp file in our temp dir; this
      * checks that it has space and access.
      * We also do some clock reporting.
-     * @param out
+     * @param out a PrintStream
      */
     private static void doReportTempDir(PrintStream out) {
         String tempdir = System.getProperty("java.io.tmpdir");

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/DirectoryScanner.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/DirectoryScanner.java b/src/main/org/apache/tools/ant/DirectoryScanner.java
index 6b52897..f4b8fdc 100644
--- a/src/main/org/apache/tools/ant/DirectoryScanner.java
+++ b/src/main/org/apache/tools/ant/DirectoryScanner.java
@@ -52,6 +52,7 @@ import org.apache.tools.ant.util.VectorSet;
  * With the selectors you can select which files you want to have included.
  * Files which are not selected are excluded. With patterns you can include
  * or exclude files based on their filename.
+ * </p>
  * <p>
  * The idea is simple. A given directory is recursively scanned for all files
  * and directories. Each file/directory is matched against a set of selectors,
@@ -60,11 +61,13 @@ import org.apache.tools.ant.util.VectorSet;
  * pattern of the include pattern list or other file selector, and don't match
  * any pattern of the exclude pattern list or fail to match against a required
  * selector will be placed in the list of files/directories found.
+ * </p>
  * <p>
  * When no list of include patterns is supplied, "**" will be used, which
  * means that everything will be matched. When no list of exclude patterns is
  * supplied, an empty list is used, such that nothing will be excluded. When
  * no selectors are supplied, none are applied.
+ * </p>
  * <p>
  * The filename pattern matching is done as follows:
  * The name to be matched is split up in path segments. A path segment is the
@@ -73,41 +76,54 @@ import org.apache.tools.ant.util.VectorSet;
  * For example, "abc/def/ghi/xyz.java" is split up in the segments "abc",
  * "def","ghi" and "xyz.java".
  * The same is done for the pattern against which should be matched.
+ * </p>
  * <p>
  * The segments of the name and the pattern are then matched against each
  * other. When '**' is used for a path segment in the pattern, it matches
  * zero or more path segments of the name.
+ * </p>
  * <p>
  * There is a special case regarding the use of <code>File.separator</code>s
- * at the beginning of the pattern and the string to match:<br>
- * When a pattern starts with a <code>File.separator</code>, the string
- * to match must also start with a <code>File.separator</code>.
- * When a pattern does not start with a <code>File.separator</code>, the
- * string to match may not start with a <code>File.separator</code>.
- * When one of these rules is not obeyed, the string will not
- * match.
+ * at the beginning of the pattern and the string to match:
+ * </p>
+ * <ul>
+ * <li>When a pattern starts with a <code>File.separator</code>, the string
+ * to match must also start with a <code>File.separator</code>.</li>
+ * <li>When a pattern does not start with a <code>File.separator</code>, the
+ * string to match may not start with a <code>File.separator</code>.</li>
+ * <li>When one of the above rules is not obeyed, the string will not
+ * match.</li>
+ * </ul>
  * <p>
  * When a name path segment is matched against a pattern path segment, the
  * following special characters can be used:<br>
  * '*' matches zero or more characters<br>
  * '?' matches one character.
+ * </p>
  * <p>
  * Examples:
+ * </p>
  * <p>
  * "**\*.class" matches all .class files/dirs in a directory tree.
+ * </p>
  * <p>
  * "test\a??.java" matches all files/dirs which start with an 'a', then two
  * more characters and then ".java", in a directory called test.
+ * </p>
  * <p>
  * "**" matches everything in a directory tree.
+ * </p>
  * <p>
  * "**\test\**\XYZ*" matches all files/dirs which start with "XYZ" and where
  * there is a parent directory called test (e.g. "abc\test\def\ghi\XYZ123").
+ * </p>
  * <p>
  * Case sensitivity may be turned off if necessary. By default, it is
  * turned on.
+ * </p>
  * <p>
  * Example of usage:
+ * </p>
  * <pre>
  *   String[] includes = {"**\\*.class"};
  *   String[] excludes = {"modules\\*\\**"};
@@ -701,6 +717,7 @@ public class DirectoryScanner
      * The maximum number of times a symbolic link may be followed
      * during a scan.
      *
+     * @param max int
      * @since Ant 1.8.0
      */
     public void setMaxLevelsOfSymlinks(final int max) {
@@ -790,7 +807,7 @@ public class DirectoryScanner
      * <code>File.separatorChar</code>, so the separator used need not
      * match <code>File.separatorChar</code>.
      *
-     * <p> When a pattern ends with a '/' or '\', "**" is appended.
+     * <p>When a pattern ends with a '/' or '\', "**" is appended.</p>
      *
      * @since Ant 1.6.3
      */
@@ -1378,7 +1395,7 @@ public class DirectoryScanner
      * Test whether or not a name matches against at least one include
      * pattern.
      *
-     * @param name The name to match. Must not be <code>null</code>.
+     * @param path The tokenized path to match. Must not be <code>null</code>.
      * @return <code>true</code> when the name matches against at least one
      *         include pattern, or <code>false</code> otherwise.
      */

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/IntrospectionHelper.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/IntrospectionHelper.java b/src/main/org/apache/tools/ant/IntrospectionHelper.java
index 2b31e43..9740338 100644
--- a/src/main/org/apache/tools/ant/IntrospectionHelper.java
+++ b/src/main/org/apache/tools/ant/IntrospectionHelper.java
@@ -812,7 +812,7 @@ public final class IntrospectionHelper {
      * Helper method to extract the inner fault from an {@link InvocationTargetException}, and turn
      * it into a BuildException. If it is already a BuildException, it is type cast and returned; if
      * not a new BuildException is created containing the child as nested text.
-     * @param ite
+     * @param ite the exception
      * @return the nested exception
      */
     private static BuildException extractBuildException(final InvocationTargetException ite) {
@@ -1529,7 +1529,7 @@ public final class IntrospectionHelper {
      * @param elementName name of the element
      * @return a nested creator, or null if there is no component of the given name, or it
      *        has no matching add type methods
-     * @throws BuildException
+     * @throws BuildException if something goes wrong
      */
     private NestedCreator createAddTypeCreator(
             final Project project, final Object parent, final String elementName) throws BuildException {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/MagicNames.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/MagicNames.java b/src/main/org/apache/tools/ant/MagicNames.java
index 67ab8a8..7c17c05 100644
--- a/src/main/org/apache/tools/ant/MagicNames.java
+++ b/src/main/org/apache/tools/ant/MagicNames.java
@@ -252,7 +252,7 @@ public final class MagicNames {
     /**
      * Name of the project reference holding an instance of {@link
      * org.apache.tools.ant.taskdefs.launcher.CommandLauncher} to use
-     * when executing commands with the help of an external skript.
+     * when executing commands with the help of an external script.
      *
      * <p>Alternatively this is the name of a system property holding
      * the fully qualified class name of a {@link
@@ -266,7 +266,7 @@ public final class MagicNames {
     /**
      * Name of the project reference holding an instance of {@link
      * org.apache.tools.ant.taskdefs.launcher.CommandLauncher} to use
-     * when executing commands without the help of an external skript.
+     * when executing commands without the help of an external script.
      *
      * <p>Alternatively this is the name of a system property holding
      * the fully qualified class name of a {@link

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/Main.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/Main.java b/src/main/org/apache/tools/ant/Main.java
index a7d4776..33dae8c 100644
--- a/src/main/org/apache/tools/ant/Main.java
+++ b/src/main/org/apache/tools/ant/Main.java
@@ -1275,9 +1275,6 @@ public class Main implements AntMain {
      *                     no descriptions are displayed.
      *                     If non-<code>null</code>, this should have
      *                     as many elements as <code>names</code>.
-     * @param topDependencies The list of dependencies for each target.
-     *                        The dependencies are listed as a non null
-     *                        enumeration of String.
      * @param heading The heading to display.
      *                Should not be <code>null</code>.
      * @param maxlen The maximum length of the names of the targets.

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/Project.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/ProjectComponent.java b/src/main/org/apache/tools/ant/ProjectComponent.java
index ad92a31..767d0c0 100644
--- a/src/main/org/apache/tools/ant/ProjectComponent.java
+++ b/src/main/org/apache/tools/ant/ProjectComponent.java
@@ -146,7 +146,7 @@ public abstract class ProjectComponent implements Cloneable {
             getProject().log(msg, msgLevel);
         } else {
             // 'reasonable' default, if the component is used without
-            // a Project ( for example as a standalone Bean ).
+            // a Project (for example as a standalone Bean).
             // Most ant components can be used this way.
             if (msgLevel <= Project.MSG_INFO) {
                 System.err.println(msg);

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/ProjectHelper.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/ProjectHelper.java b/src/main/org/apache/tools/ant/ProjectHelper.java
index ab39368..0c73b26 100644
--- a/src/main/org/apache/tools/ant/ProjectHelper.java
+++ b/src/main/org/apache/tools/ant/ProjectHelper.java
@@ -151,8 +151,8 @@ public class ProjectHelper {
     }
 
     // -------------------- Common properties  --------------------
-    // The following properties are required by import ( and other tasks
-    // that read build files using ProjectHelper ).
+    // The following properties are required by import (and other tasks
+    // that read build files using ProjectHelper).
 
     private Vector<Object> importStack = new Vector<Object>();
     private List<String[]> extensionStack = new LinkedList<String[]>();
@@ -199,6 +199,7 @@ public class ProjectHelper {
     /**
      * Sets the prefix to prepend to imported target names.
      *
+     * @param prefix String
      * @since Ant 1.8.0
      */
     public static void setCurrentTargetPrefix(String prefix) {
@@ -216,6 +217,7 @@ public class ProjectHelper {
      *
      * <p>May be set by &lt;import&gt;'s prefixSeparator attribute.</p>
      *
+     * @return String
      * @since Ant 1.8.0
      */
     public static String getCurrentPrefixSeparator() {
@@ -225,6 +227,7 @@ public class ProjectHelper {
     /**
      * Sets the separator between the prefix and the target name.
      *
+     * @param sep String
      * @since Ant 1.8.0
      */
     public static void setCurrentPrefixSeparator(String sep) {
@@ -250,6 +253,7 @@ public class ProjectHelper {
      * overwritten in the importing build file.  The depends list of
      * the imported targets is not modified at all.</p>
      *
+     * @return boolean
      * @since Ant 1.8.0
      */
     public static boolean isInIncludeMode() {
@@ -260,6 +264,7 @@ public class ProjectHelper {
      * Sets whether the current file should be read in include as
      * opposed to import mode.
      *
+     * @param includeMode boolean
      * @since Ant 1.8.0
      */
     public static void setInIncludeMode(boolean includeMode) {
@@ -591,6 +596,8 @@ public class ProjectHelper {
      *
      * <p>This implementation returns false.</p>
      *
+     * @param r Resource
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean canParseAntlibDescriptor(Resource r) {
@@ -601,6 +608,9 @@ public class ProjectHelper {
      * Parse the given URL as an antlib descriptor and return the
      * content as something that can be turned into an Antlib task.
      *
+     * @param containingProject Project
+     * @param source Resource
+     * @return UnknownElement
      * @since ant 1.8.0
      */
     public UnknownElement parseAntlibDescriptor(Project containingProject,

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/ProjectHelperRepository.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/ProjectHelperRepository.java b/src/main/org/apache/tools/ant/ProjectHelperRepository.java
index e370a54..df5d1a0 100644
--- a/src/main/org/apache/tools/ant/ProjectHelperRepository.java
+++ b/src/main/org/apache/tools/ant/ProjectHelperRepository.java
@@ -79,7 +79,7 @@ public class ProjectHelperRepository {
         Constructor<? extends ProjectHelper> projectHelper = getProjectHelperBySystemProperty();
         registerProjectHelper(projectHelper);
 
-        // A JDK1.3 'service' ( like in JAXP ). That will plug a helper
+        // A JDK1.3 'service' (like in JAXP). That will plug a helper
         // automatically if in CLASSPATH, with the right META-INF/services.
         try {
             ClassLoader classLoader = LoaderUtils.getContextClassLoader();
@@ -248,6 +248,7 @@ public class ProjectHelperRepository {
      * Get the helper that will be able to parse the specified build file. The helper
      * will be chosen among the ones found in the classpath
      *
+     * @param buildFile Resource
      * @return the first ProjectHelper that fit the requirement (never <code>null</code>).
      */
     public ProjectHelper getProjectHelperForBuildFile(Resource buildFile) throws BuildException {
@@ -271,6 +272,7 @@ public class ProjectHelperRepository {
      * Get the helper that will be able to parse the specified antlib. The helper
      * will be chosen among the ones found in the classpath
      *
+     * @param antlib Resource
      * @return the first ProjectHelper that fit the requirement (never <code>null</code>).
      */
     public ProjectHelper getProjectHelperForAntlib(Resource antlib) throws BuildException {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/PropertyHelper.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/PropertyHelper.java b/src/main/org/apache/tools/ant/PropertyHelper.java
index 1dbb280..9f94bda 100644
--- a/src/main/org/apache/tools/ant/PropertyHelper.java
+++ b/src/main/org/apache/tools/ant/PropertyHelper.java
@@ -72,7 +72,7 @@ import org.apache.tools.ant.property.PropertyExpander;
  * parseProperties} inside the ParseProperties class which in turn
  * uses the {@link org.apache.tools.ant.property.PropertyExpander
  * PropertyExpander delegates} to find properties inside the string
- * and this class to expand the propertiy names found into the
+ * and this class to expand the property names found into the
  * corresponding values.</p>
  *
  * <p>When {@link #getProperty looking up a property value} this class
@@ -1111,6 +1111,7 @@ public class PropertyHelper implements GetProperty {
     /**
      * Get the Collection of delegates of the specified type.
      *
+     * @param <D> desired type.
      * @param type
      *            delegate type.
      * @return Collection.
@@ -1149,6 +1150,8 @@ public class PropertyHelper implements GetProperty {
     /**
      * If the given object can be interpreted as a true/false value,
      * turn it into a matching Boolean - otherwise return null.
+     * @param value Object
+     * @return Boolean
      * @since Ant 1.8.0
      */
     public static Boolean toBoolean(Object value) {
@@ -1172,6 +1175,8 @@ public class PropertyHelper implements GetProperty {
     /**
      * Returns true if the object is null or an empty string.
      *
+     * @param value Object
+     * @return boolean
      * @since Ant 1.8.0
      */
     private static boolean nullOrEmpty(Object value) {
@@ -1183,6 +1188,8 @@ public class PropertyHelper implements GetProperty {
      * Returns true if the value can be interpreted as a true value or
      * cannot be interpreted as a false value and a property of the
      * value's name exists.
+     * @param value Object
+     * @return boolean
      * @since Ant 1.8.0
      */
     private boolean evalAsBooleanOrPropertyName(Object value) {
@@ -1197,6 +1204,8 @@ public class PropertyHelper implements GetProperty {
      * Returns true if the value is null or an empty string, can be
      * interpreted as a true value or cannot be interpreted as a false
      * value and a property of the value's name exists.
+     * @param value Object
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean testIfCondition(Object value) {
@@ -1207,6 +1216,8 @@ public class PropertyHelper implements GetProperty {
      * Returns true if the value is null or an empty string, can be
      * interpreted as a false value or cannot be interpreted as a true
      * value and a property of the value's name doesn't exist.
+     * @param value Object
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean testUnlessCondition(Object value) {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/RuntimeConfigurable.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/RuntimeConfigurable.java b/src/main/org/apache/tools/ant/RuntimeConfigurable.java
index 0aafccb..302d8f6 100644
--- a/src/main/org/apache/tools/ant/RuntimeConfigurable.java
+++ b/src/main/org/apache/tools/ant/RuntimeConfigurable.java
@@ -70,7 +70,7 @@ public class RuntimeConfigurable implements Serializable {
     private transient boolean namespacedAttribute = false;
 
     /** Attribute names and values. While the XML spec doesn't require
-     *  preserving the order ( AFAIK ), some ant tests do rely on the
+     *  preserving the order (AFAIK), some ant tests do rely on the
      *  exact order.
      * The only exception to this order is the treatment of
      * refid. A number of datatypes check if refid is set
@@ -172,7 +172,7 @@ public class RuntimeConfigurable implements Serializable {
      * are any Ant attributes, and if so, the method calls the
      * isEnabled() method on them.
      * @param owner the UE that owns this RC.
-     * @return true if enabled, false if any of the ant attribures return
+     * @return true if enabled, false if any of the ant attributes return
      *              false.
      * @since 1.9.1
      */
@@ -267,10 +267,11 @@ public class RuntimeConfigurable implements Serializable {
     /**
      * Sets the attributes for the wrapped element.
      *
-     * @deprecated since 1.6.x.
      * @param attributes List of attributes defined in the XML for this
      *                   element. May be <code>null</code>.
+     * @deprecated since 1.6.x.
      */
+    @Deprecated
     public synchronized void setAttributes(AttributeList attributes) {
         this.attributes = new AttributeListImpl(attributes);
         for (int i = 0; i < attributes.getLength(); i++) {
@@ -341,10 +342,11 @@ public class RuntimeConfigurable implements Serializable {
     /**
      * Returns the list of attributes for the wrapped element.
      *
-     * @deprecated Deprecated since Ant 1.6 in favor of {@link #getAttributeMap}.
      * @return An AttributeList representing the attributes defined in the
      *         XML for this element. May be <code>null</code>.
+     * @deprecated Deprecated since Ant 1.6 in favor of {@link #getAttributeMap}.
      */
+    @Deprecated
     public synchronized AttributeList getAttributes() {
         return attributes;
     }
@@ -415,7 +417,7 @@ public class RuntimeConfigurable implements Serializable {
 
     /**
      * Get the text content of this element. Various text chunks are
-     * concatenated, there is no way ( currently ) of keeping track of
+     * concatenated, there is no way (currently) of keeping track of
      * multiple fragments.
      *
      * @return the text content of this element.
@@ -449,9 +451,10 @@ public class RuntimeConfigurable implements Serializable {
      * and then each child is configured and added. Each time the
      * wrapper is configured, the attributes and text for it are
      * reset.
-     *
+     * <p>
      * If the element has an <code>id</code> attribute, a reference
      * is added to the project as well.
+     * </p>
      *
      * @param p The project containing the wrapped element.
      *          Must not be <code>null</code>.
@@ -468,18 +471,18 @@ public class RuntimeConfigurable implements Serializable {
      * Configures the wrapped element.  The attributes and text for
      * the wrapped element are configured.  Each time the wrapper is
      * configured, the attributes and text for it are reset.
-     *
+     * <p>
      * If the element has an <code>id</code> attribute, a reference
      * is added to the project as well.
+     * </p>
      *
      * @param p The project containing the wrapped element.
      *          Must not be <code>null</code>.
      *
      * @param configureChildren ignored.
-
      *
      * @exception BuildException if the configuration fails, for instance due
-     *            to invalid attributes , or text being added to
+     *            to invalid attributes, or text being added to
      *            an element which doesn't accept it.
      */
     public synchronized void maybeConfigure(Project p, boolean configureChildren)
@@ -540,7 +543,7 @@ public class RuntimeConfigurable implements Serializable {
                 } catch (BuildException be) {
                     if (name.equals("id")) {
                         // Assume that this is an not supported attribute type
-                        // thrown for example by a dymanic attribute task
+                        // thrown for example by a dynamic attribute task
                         // Do nothing
                     } else {
                         throw be;

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/Target.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/Target.java b/src/main/org/apache/tools/ant/Target.java
index b1df2b2..33b8b72 100644
--- a/src/main/org/apache/tools/ant/Target.java
+++ b/src/main/org/apache/tools/ant/Target.java
@@ -301,6 +301,7 @@ public class Target implements TaskContainer {
     /**
      * Same as {@link #setIf(String)} but requires a {@link Condition} instance
      *
+     * @param condition Condition
      * @since 1.9
      */
     public void setIf(Condition condition) {
@@ -348,6 +349,7 @@ public class Target implements TaskContainer {
     /**
      * Same as {@link #setUnless(String)} but requires a {@link Condition} instance
      *
+     * @param condition Condition
      * @since 1.9
      */
     public void setUnless(Condition condition) {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/TaskAdapter.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/TaskAdapter.java b/src/main/org/apache/tools/ant/TaskAdapter.java
index 3a3001f..d4d8c32 100644
--- a/src/main/org/apache/tools/ant/TaskAdapter.java
+++ b/src/main/org/apache/tools/ant/TaskAdapter.java
@@ -44,7 +44,7 @@ public class TaskAdapter extends Task implements TypeAdapter {
      * Constructor for given proxy.
      * So you could write easier code
      * <pre>
-     * myTaskContainer.addTask( new TaskAdapter(myProxy) );
+     * myTaskContainer.addTask(new TaskAdapter(myProxy));
      * </pre>
      *
      * @param proxy The object which Ant should use as task.

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/TaskConfigurationChecker.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/TaskConfigurationChecker.java b/src/main/org/apache/tools/ant/TaskConfigurationChecker.java
index e8e7444..9a52043 100644
--- a/src/main/org/apache/tools/ant/TaskConfigurationChecker.java
+++ b/src/main/org/apache/tools/ant/TaskConfigurationChecker.java
@@ -95,7 +95,7 @@ public class TaskConfigurationChecker {
     public void checkErrors() throws BuildException {
         if (!errors.isEmpty()) {
             StringBuffer sb = new StringBuffer();
-            sb.append("Configurationerror on <");
+            sb.append("Configuration error on <");
             sb.append(task.getTaskName());
             sb.append(">:");
             sb.append(System.getProperty("line.separator"));

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/dispatch/DispatchTask.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/dispatch/DispatchTask.java b/src/main/org/apache/tools/ant/dispatch/DispatchTask.java
index a848ed1..b88b873 100644
--- a/src/main/org/apache/tools/ant/dispatch/DispatchTask.java
+++ b/src/main/org/apache/tools/ant/dispatch/DispatchTask.java
@@ -23,8 +23,7 @@ import org.apache.tools.ant.Task;
  * Tasks extending this class may contain multiple actions.
  * The method that is invoked for execution depends upon the
  * value of the action attribute of the task.
- * <br>
- * Example:<br>
+ * <p>Example:</p>
  * &lt;mytask action=&quot;list&quot;/&gt; will invoke the method
  * with the signature public void list() in mytask's class.
  * If the action attribute is not defined in the task or is empty,

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/BaseParamFilterReader.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/BaseParamFilterReader.java b/src/main/org/apache/tools/ant/filters/BaseParamFilterReader.java
index 54bc9ff..f3a8e5e 100644
--- a/src/main/org/apache/tools/ant/filters/BaseParamFilterReader.java
+++ b/src/main/org/apache/tools/ant/filters/BaseParamFilterReader.java
@@ -58,7 +58,7 @@ public abstract class BaseParamFilterReader
      * @param parameters The parameters to be used by this filter.
      *                   Should not be <code>null</code>.
      */
-    public final void setParameters(final Parameter[] parameters) {
+    public final void setParameters(final Parameter... parameters) {
         this.parameters = parameters;
         setInitialized(false);
     }

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/ClassConstants.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/ClassConstants.java b/src/main/org/apache/tools/ant/filters/ClassConstants.java
index 3544301..b6894f9 100644
--- a/src/main/org/apache/tools/ant/filters/ClassConstants.java
+++ b/src/main/org/apache/tools/ant/filters/ClassConstants.java
@@ -29,8 +29,7 @@ import org.apache.tools.ant.util.ResourceUtils;
  * Assembles the constants declared in a Java class in
  * <code>key1=value1(line separator)key2=value2</code>
  * format.
- *<p>
- * Notes:
+ *<p>Notes:</p>
  * <ol>
  * <li>This filter uses the BCEL external toolkit.
  * <li>This assembles only those constants that are not created
@@ -39,7 +38,7 @@ import org.apache.tools.ant.util.ResourceUtils;
  * and String only.</li>
  * <li>The access modifiers of the declared constants do not matter.</li>
  *</ol>
- * Example:<br>
+ * <p>Example:</p>
  * <pre>&lt;classconstants/&gt;</pre>
  * Or:
  * <pre>&lt;filterreader

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/ExpandProperties.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/ExpandProperties.java b/src/main/org/apache/tools/ant/filters/ExpandProperties.java
index 524a799..48d9ffe 100644
--- a/src/main/org/apache/tools/ant/filters/ExpandProperties.java
+++ b/src/main/org/apache/tools/ant/filters/ExpandProperties.java
@@ -30,8 +30,7 @@ import org.apache.tools.ant.types.PropertySet;
 
 /**
  * Expands Ant properties, if any, in the data.
- * <p>
- * Example:<br>
+ * <p>Example:</p>
  * <pre>&lt;expandproperties/&gt;</pre>
  * Or:
  * <pre>&lt;filterreader

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/FixCrLfFilter.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/FixCrLfFilter.java b/src/main/org/apache/tools/ant/filters/FixCrLfFilter.java
index 8a37924..b5a0ad2 100644
--- a/src/main/org/apache/tools/ant/filters/FixCrLfFilter.java
+++ b/src/main/org/apache/tools/ant/filters/FixCrLfFilter.java
@@ -29,13 +29,14 @@ import org.apache.tools.ant.types.EnumeratedAttribute;
  * damaged by misconfigured or misguided editors or file transfer programs.
  * <p>
  * This filter can take the following arguments:
+ * </p>
  * <ul>
- * <li>eof
- * <li>eol
- * <li>fixlast
- * <li>javafiles
- * <li>tab
- * <li>tablength
+ * <li>eof</li>
+ * <li>eol</li>
+ * <li>fixlast</li>
+ * <li>javafiles</li>
+ * <li>tab</li>
+ * <li>tablength</li>
  * </ul>
  * None of which are required.
  * <p>
@@ -44,6 +45,7 @@ import org.apache.tools.ant.types.EnumeratedAttribute;
  * handling has also been generalised to accommodate any tabwidth from 2 to 80,
  * inclusive. Importantly, it can leave untouched any literal TAB characters
  * embedded within Java string or character constants.
+ * </p>
  * <p>
  * <em>Caution:</em> run with care on carefully formatted files. This may
  * sound obvious, but if you don't specify asis, presume that your files are
@@ -53,22 +55,19 @@ import org.apache.tools.ant.types.EnumeratedAttribute;
  * cr="add" can result in CR characters being removed in one special case
  * accommodated, i.e., CRCRLF is regarded as a single EOL to handle cases where
  * other programs have converted CRLF into CRCRLF.
- *
- * <P>
+ *</p>
+ * <p>
  * Example:
- *
+ * </p>
  * <pre>
  * &lt;&lt;fixcrlf tab=&quot;add&quot; eol=&quot;crlf&quot; eof=&quot;asis&quot;/&gt;
  * </pre>
- *
  * Or:
- *
  * <pre>
  * &lt;filterreader classname=&quot;org.apache.tools.ant.filters.FixCrLfFilter&quot;&gt;
  *   &lt;param eol=&quot;crlf&quot; tab=&quot;asis&quot;/&gt;
  *  &lt;/filterreader&gt;
  * </pre>
- *
  */
 public final class FixCrLfFilter extends BaseParamFilterReader implements ChainableReader {
     private static final int DEFAULT_TAB_LENGTH = 8;
@@ -946,8 +945,8 @@ public final class FixCrLfFilter extends BaseParamFilterReader implements Chaina
 
         /**
          * @see EnumeratedAttribute#getValues
+         * {@inheritDoc}.
          */
-        /** {@inheritDoc}. */
         public String[] getValues() {
             return new String[] {"asis", "cr", "lf", "crlf", "mac", "unix", "dos"};
         }

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/LineContainsRegExp.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/LineContainsRegExp.java b/src/main/org/apache/tools/ant/filters/LineContainsRegExp.java
index 09dce77..5d144c2 100644
--- a/src/main/org/apache/tools/ant/filters/LineContainsRegExp.java
+++ b/src/main/org/apache/tools/ant/filters/LineContainsRegExp.java
@@ -204,7 +204,8 @@ public final class LineContainsRegExp
     }
 
     /**
-     * Whether to match casesensitevly.
+     * Whether to match casesensitively.
+     * @param b boolean
      * @since Ant 1.8.2
      */
     public void setCaseSensitive(boolean b) {
@@ -221,6 +222,7 @@ public final class LineContainsRegExp
 
     /**
      * Set the regular expression as an attribute.
+     * @param pattern String
      * @since Ant 1.9.10
      */
     public void setRegexp(String pattern) {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/ReplaceTokens.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/ReplaceTokens.java b/src/main/org/apache/tools/ant/filters/ReplaceTokens.java
index bcbc312..f033b6f 100644
--- a/src/main/org/apache/tools/ant/filters/ReplaceTokens.java
+++ b/src/main/org/apache/tools/ant/filters/ReplaceTokens.java
@@ -217,6 +217,7 @@ public final class ReplaceTokens
      * A resource containing properties, each of which is interpreted
      * as a token/value pair.
      *
+     * @param r Resource
      * @since Ant 1.8.0
      */
     public void setPropertiesResource(Resource r) {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/filters/SortFilter.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/filters/SortFilter.java b/src/main/org/apache/tools/ant/filters/SortFilter.java
index 44e8d72..056ad6a 100644
--- a/src/main/org/apache/tools/ant/filters/SortFilter.java
+++ b/src/main/org/apache/tools/ant/filters/SortFilter.java
@@ -82,10 +82,10 @@ import org.apache.tools.ant.types.Parameter;
  *
  * <p>
  * Sort all files <code>*.txt</code> from <i>src</i> location using as
- * sorting criterium <code>EvenFirstCmp</code> class, that sorts the file
+ * sorting criterion <code>EvenFirstCmp</code> class, that sorts the file
  * lines putting even lines first then odd lines for example. The modified files
  * are copied into <i>build</i> location. The <code>EvenFirstCmp</code>,
- * has to an instanciable class via <code>Class.newInstance()</code>,
+ * has to an instantiable class via <code>Class.newInstance()</code>,
  * therefore in case of inner class has to be <em>static</em>. It also has to
  * implement <code>java.util.Comparator</code> interface, for example:
  * </p>
@@ -102,7 +102,7 @@ import org.apache.tools.ant.types.Parameter;
  *
  * <p>The example above is equivalent to:</p>
  *
- * <blockquote><pre>
+ * <pre>
  *   &lt;componentdef name="evenfirst"
  *                 classname="org.apache.tools.ant.filters.EvenFirstCmp&quot;/&gt;
  *   &lt;copy todir=&quot;build&quot;&gt;
@@ -113,10 +113,10 @@ import org.apache.tools.ant.types.Parameter;
  *           &lt;/sortfilter&gt;
  *       &lt;/filterchain&gt;
  *   &lt;/copy&gt;
- * </pre></blockquote>
+ * </pre>
  *
- * <p> If parameter <code>comparator</code> is present, then
- * <code>reverse</code> parameter will not be taken into account.  </p>
+ * <p>If parameter <code>comparator</code> is present, then
+ * <code>reverse</code> parameter will not be taken into account.</p>
  *
  * @since Ant 1.8.0
  */
@@ -285,7 +285,7 @@ public final class SortFilter extends BaseParamFilterReader
     }
 
     /**
-     * Set the comparator to be used as sorting criterium.
+     * Set the comparator to be used as sorting criterion.
      *
      * @param comparator
      *            the comparator to set

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/helper/AntXMLContext.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/helper/AntXMLContext.java b/src/main/org/apache/tools/ant/helper/AntXMLContext.java
index 99e3d1a..393ad5c 100644
--- a/src/main/org/apache/tools/ant/helper/AntXMLContext.java
+++ b/src/main/org/apache/tools/ant/helper/AntXMLContext.java
@@ -84,8 +84,8 @@ public class AntXMLContext {
       */
     private Target implicitTarget = new Target();
 
-    /** Current target ( no need for a stack as the processing model
-        allows only one level of target ) */
+    /** Current target (no need for a stack as the processing model
+        allows only one level of target) */
     private Target currentTarget = null;
 
     /** The stack of RuntimeConfigurable2 wrapping the
@@ -138,7 +138,8 @@ public class AntXMLContext {
 
     /**
      * sets the build file to which the XML context belongs
-     * @param buildFile  ant build file
+     * @param buildFile Ant build file
+     * @throws MalformedURLException if parent URL cannot be constructed
      * @since Ant 1.8.0
      */
     public void setBuildFile(URL buildFile) throws MalformedURLException {
@@ -151,7 +152,7 @@ public class AntXMLContext {
 
     /**
      * find out the build file
-     * @return  the build file to which the xml context belongs
+     * @return the build file to which the XML context belongs
      */
     public File getBuildFile() {
         return buildFile;
@@ -167,7 +168,7 @@ public class AntXMLContext {
 
     /**
      * find out the build file
-     * @return  the build file to which the xml context belongs
+     * @return the build file to which the xml context belongs
      * @since Ant 1.8.0
      */
     public URL getBuildFileURL() {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/helper/ProjectHelper2.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/helper/ProjectHelper2.java b/src/main/org/apache/tools/ant/helper/ProjectHelper2.java
index 2e9c725..6ae2d32 100644
--- a/src/main/org/apache/tools/ant/helper/ProjectHelper2.java
+++ b/src/main/org/apache/tools/ant/helper/ProjectHelper2.java
@@ -483,8 +483,8 @@ public class ProjectHelper2 extends ProjectHelper {
 
     /**
      * Handler for ant processing. Uses a stack of AntHandlers to
-     * implement each element ( the original parser used a recursive behavior,
-     * with the implicit execution stack )
+     * implement each element (the original parser used a recursive behavior,
+     * with the implicit execution stack)
      */
     public static class RootHandler extends DefaultHandler {
         private Stack<AntHandler> antHandlers = new Stack<AntHandler>();
@@ -706,11 +706,11 @@ public class ProjectHelper2 extends ProjectHelper {
              * too 'involved' in the processing. A better solution (IMO)
              * would be to create UE for Project and Target too, and
              * then process the tree and have Project/Target deal with
-             * its attributes ( similar with Description ).
+             * its attributes (similar with Description).
              *
-             * If we eventually switch to ( or add support for ) DOM,
+             * If we eventually switch to (or add support for) DOM,
              * things will work smoothly - UE can be avoided almost completely
-             * ( it could still be created on demand, for backward compatibility )
+             * (it could still be created on demand, for backward compatibility)
              */
 
             for (int i = 0; i < attrs.getLength(); i++) {
@@ -760,7 +760,7 @@ public class ProjectHelper2 extends ProjectHelper {
                 }
             }
 
-            // TODO Move to Project ( so it is shared by all helpers )
+            // TODO Move to Project (so it is shared by all helpers)
             String antFileProp =
                 MagicNames.ANT_FILE + "." + context.getCurrentProjectName();
             String dup = project.getProperty(antFileProp);
@@ -1081,7 +1081,7 @@ public class ProjectHelper2 extends ProjectHelper {
     }
 
     /**
-     * Handler for all project elements ( tasks, data types )
+     * Handler for all project elements (tasks, data types)
      */
     public static class ElementHandler extends AntHandler {
 
@@ -1136,7 +1136,7 @@ public class ProjectHelper2 extends ProjectHelper {
                 // Nested element
                 ((UnknownElement) parent).addChild(task);
             }  else {
-                // Task included in a target ( including the default one ).
+                // Task included in a target (including the default one).
                 context.getCurrentTarget().addTask(task);
             }
 

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/helper/ProjectHelperImpl.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/helper/ProjectHelperImpl.java b/src/main/org/apache/tools/ant/helper/ProjectHelperImpl.java
index 97c42a0..ebed3a2 100644
--- a/src/main/org/apache/tools/ant/helper/ProjectHelperImpl.java
+++ b/src/main/org/apache/tools/ant/helper/ProjectHelperImpl.java
@@ -187,8 +187,8 @@ public class ProjectHelperImpl extends ProjectHelper {
         protected DocumentHandler parentHandler;
 
         /** Helper impl. With non-static internal classes, the compiler will generate
-            this automatically - but this will fail with some compilers ( reporting
-            "Expecting to find object/array on stack" ). If we pass it
+            this automatically - but this will fail with some compilers (reporting
+            "Expecting to find object/array on stack"). If we pass it
             explicitly it'll work with more compilers.
         */
         ProjectHelperImpl helperImpl;

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/helper/SingleCheckExecutor.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/helper/SingleCheckExecutor.java b/src/main/org/apache/tools/ant/helper/SingleCheckExecutor.java
index 1960ed0..6577c94 100644
--- a/src/main/org/apache/tools/ant/helper/SingleCheckExecutor.java
+++ b/src/main/org/apache/tools/ant/helper/SingleCheckExecutor.java
@@ -18,12 +18,10 @@
 
 package org.apache.tools.ant.helper;
 
-
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Executor;
 import org.apache.tools.ant.Project;
 
-
 /**
  * "Single-check" Target executor implementation.
  * Differs from {@link DefaultExecutor} in that the dependencies for all

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/launch/Launcher.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/launch/Launcher.java b/src/main/org/apache/tools/ant/launch/Launcher.java
index 534bbfb..5c4f6f4 100644
--- a/src/main/org/apache/tools/ant/launch/Launcher.java
+++ b/src/main/org/apache/tools/ant/launch/Launcher.java
@@ -69,10 +69,9 @@ public class Launcher {
 
     /**
      * The location of a per-user library directory.
-     * <p>
-     * It's value is the concatenation of {@link #ANT_PRIVATEDIR}
+     * <p>It's value is the concatenation of {@link #ANT_PRIVATEDIR}
      * with {@link #ANT_PRIVATELIB}, with an appropriate file separator
-     * in between. For example, on Unix, it's <code>.ant/lib</code>.
+     * in between. For example, on Unix, it's <code>.ant/lib</code>.</p>
      */
     public static final String USER_LIBDIR =
         ANT_PRIVATEDIR + File.separatorChar + ANT_PRIVATELIB;

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/launch/Locator.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/launch/Locator.java b/src/main/org/apache/tools/ant/launch/Locator.java
index 4640e70..7ea070e 100644
--- a/src/main/org/apache/tools/ant/launch/Locator.java
+++ b/src/main/org/apache/tools/ant/launch/Locator.java
@@ -391,14 +391,14 @@ public final class Locator {
      * File.toURL() does not encode characters like #.
      * File.toURI() has been introduced in java 1.4, so
      * Ant cannot use it (except by reflection) <!-- TODO no longer true -->
-     * FileUtils.toURI() cannot be used by Locator.java
+     * File.toURI() cannot be used by Locator.java
      * Implemented this way.
      * File.toURL() adds file: and changes '\' to '/' for dos OSes
      * encodeURI converts characters like ' ' and '#' to %DD
      * @param file the file to convert
      * @return URL the converted File
      * @throws MalformedURLException on error
-     * @deprecated since 1.9, use {@link FileUtils#getFileURL(File)}
+     * @deprecated since 1.9, use <code>FileUtils.getFileURL(File)</code>
      */
     @Deprecated
     public static URL fileToURL(File file)

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/listener/AnsiColorLogger.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/listener/AnsiColorLogger.java b/src/main/org/apache/tools/ant/listener/AnsiColorLogger.java
index 7519a7e..fb22f75 100644
--- a/src/main/org/apache/tools/ant/listener/AnsiColorLogger.java
+++ b/src/main/org/apache/tools/ant/listener/AnsiColorLogger.java
@@ -200,8 +200,8 @@ public class AnsiColorLogger extends DefaultLogger {
 
     /**
      * @see DefaultLogger#printMessage
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     @Override
     protected void printMessage(final String message,
                                 final PrintStream stream,

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/listener/BigProjectLogger.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/listener/BigProjectLogger.java b/src/main/org/apache/tools/ant/listener/BigProjectLogger.java
index 865127d..7d618bc 100644
--- a/src/main/org/apache/tools/ant/listener/BigProjectLogger.java
+++ b/src/main/org/apache/tools/ant/listener/BigProjectLogger.java
@@ -75,7 +75,7 @@ public class BigProjectLogger extends SimpleBigProjectLogger
     /**
      * {@inheritDoc}
      *
-     * @param event
+     * @param event BuildEvent
      */
     public void targetStarted(BuildEvent event) {
         maybeRaiseSubBuildStarted(event);
@@ -85,7 +85,7 @@ public class BigProjectLogger extends SimpleBigProjectLogger
     /**
      * {@inheritDoc}
      *
-     * @param event
+     * @param event BuildEvent
      */
     public void taskStarted(BuildEvent event) {
         maybeRaiseSubBuildStarted(event);
@@ -95,7 +95,7 @@ public class BigProjectLogger extends SimpleBigProjectLogger
     /**
      * {@inheritDoc}
      *
-     * @param event
+     * @param event BuildEvent
      */
     public void buildFinished(BuildEvent event) {
         maybeRaiseSubBuildStarted(event);
@@ -106,7 +106,7 @@ public class BigProjectLogger extends SimpleBigProjectLogger
     /**
      * {@inheritDoc}
      *
-     * @param event
+     * @param event BuildEvent
      */
     public void messageLogged(BuildEvent event) {
         maybeRaiseSubBuildStarted(event);

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/listener/CommonsLoggingListener.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/listener/CommonsLoggingListener.java b/src/main/org/apache/tools/ant/listener/CommonsLoggingListener.java
index 32474ee..86fd684 100644
--- a/src/main/org/apache/tools/ant/listener/CommonsLoggingListener.java
+++ b/src/main/org/apache/tools/ant/listener/CommonsLoggingListener.java
@@ -128,8 +128,8 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#targetStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void targetStarted(final BuildEvent event) {
         if (initialized) {
             final Log log = getLog(TARGET_LOG,
@@ -143,8 +143,8 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#targetFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void targetFinished(final BuildEvent event) {
         if (initialized) {
             final String targetName = event.getTarget().getName();
@@ -162,8 +162,8 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#taskStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void taskStarted(final BuildEvent event) {
         if (initialized) {
             final Task task = event.getTask();
@@ -184,8 +184,8 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#taskFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void taskFinished(final BuildEvent event) {
         if (initialized) {
             final Task task = event.getTask();
@@ -213,8 +213,8 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#messageLogged
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void messageLogged(final BuildEvent event) {
         if (initialized) {
             Object categoryObject = event.getTask();

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/listener/Log4jListener.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/listener/Log4jListener.java b/src/main/org/apache/tools/ant/listener/Log4jListener.java
index 829f118..501b511 100644
--- a/src/main/org/apache/tools/ant/listener/Log4jListener.java
+++ b/src/main/org/apache/tools/ant/listener/Log4jListener.java
@@ -55,8 +55,8 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#buildStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void buildStarted(final BuildEvent event) {
         if (initialized) {
             final Logger log = Logger.getLogger(Project.class.getName());
@@ -66,8 +66,8 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#buildFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void buildFinished(final BuildEvent event) {
         if (initialized) {
             final Logger log = Logger.getLogger(Project.class.getName());
@@ -81,8 +81,8 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#targetStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void targetStarted(final BuildEvent event) {
         if (initialized) {
             final Logger log = Logger.getLogger(Target.class.getName());
@@ -92,8 +92,8 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#targetFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void targetFinished(final BuildEvent event) {
         if (initialized) {
             final String targetName = event.getTarget().getName();
@@ -109,8 +109,8 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#taskStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void taskStarted(final BuildEvent event) {
         if (initialized) {
             final Task task = event.getTask();
@@ -121,8 +121,8 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#taskFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
     public void taskFinished(final BuildEvent event) {
         if (initialized) {
             final Task task = event.getTask();
@@ -138,6 +138,7 @@ public class Log4jListener implements BuildListener {
 
     /**
      * @see BuildListener#messageLogged
+     * {@inheritDoc}.
      */
     /** {@inheritDoc}. */
     public void messageLogged(final BuildEvent event) {

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/listener/MailLogger.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/listener/MailLogger.java b/src/main/org/apache/tools/ant/listener/MailLogger.java
index 45289a1..2de55bf 100644
--- a/src/main/org/apache/tools/ant/listener/MailLogger.java
+++ b/src/main/org/apache/tools/ant/listener/MailLogger.java
@@ -323,8 +323,6 @@ public class MailLogger extends DefaultLogger {
      * @param  defaultValue   value returned if not present in the properties.
      *      Set to null to make required.
      * @return                The value of the property, or default value.
-     * @exception  Exception  thrown if no default value is specified and the
-     *      property is not present in properties.
      */
     private String getValue(Hashtable<String, Object> properties, String name,
                             String defaultValue) {
diff --git a/src/main/org/apache/tools/ant/Project.java b/src/main/org/apache/tools/ant/Project.java
index 34dddb2..b91b83e 100644
--- a/src/main/org/apache/tools/ant/Project.java
+++ b/src/main/org/apache/tools/ant/Project.java
@@ -882,7 +882,7 @@ public class Project implements ResourceFactory {
     /**
      * Set &quot;keep-going&quot; mode. In this mode Ant will try to execute
      * as many targets as possible. All targets that do not depend
-     * on failed target(s) will be executed.  If the keepGoing settor/getter
+     * on failed target(s) will be executed.  If the keepGoing setter/getter
      * methods are used in conjunction with the <code>ant.executor.class</code>
      * property, they will have no effect.
      * @param keepGoingMode &quot;keep-going&quot; mode
@@ -893,7 +893,7 @@ public class Project implements ResourceFactory {
     }
 
     /**
-     * Return the keep-going mode.  If the keepGoing settor/getter
+     * Return the keep-going mode.  If the keepGoing setter/getter
      * methods are used in conjunction with the <code>ant.executor.class</code>
      * property, they will have no effect.
      * @return &quot;keep-going&quot; mode
@@ -1803,13 +1803,13 @@ public class Project implements ResourceFactory {
     /**
      * Topologically sort a set of targets.
      *
      * @param root <code>String[]</code> containing the names of the root targets.
      *             The sort is created in such a way that the ordered sequence of
      *             Targets is the minimum possible such sequence to the specified
      *             root targets.
      *             Must not be <code>null</code>.
      * @param targetTable A map of names to targets (String to Target).
-     *                Must not be <code>null</code>.
+     *                    Must not be <code>null</code>.
      * @param returnAll <code>boolean</code> indicating whether to return all
      *                  targets, or the execution sequence only.
      * @return a Vector of Target objects in sorted order.
@@ -1817,7 +1817,7 @@ public class Project implements ResourceFactory {
      *                           targets, or if a named target does not exist.
      * @since Ant 1.6.3
      */
-    public final Vector<Target> topoSort(final String[] root, final Hashtable<String, Target> targetTable,
+    public final Vector<Target> topoSort(final String[] roots, final Hashtable<String, Target> targetTable,
                                  final boolean returnAll) throws BuildException {
         final Vector<Target> ret = new VectorSet<Target>();
         final Hashtable<String, String> state = new Hashtable<String, String>();
@@ -1831,19 +1831,19 @@ public class Project implements ResourceFactory {
         // dependency tree, not just on the Targets that depend on the
         // build Target.
 
-        for (int i = 0; i < root.length; i++) {
-            final String st = (state.get(root[i]));
+        for (int i = 0; i < roots.length; i++) {
+            final String st = (state.get(roots[i]));
             if (st == null) {
-                tsort(root[i], targetTable, state, visiting, ret);
+                tsort(roots[i], targetTable, state, visiting, ret);
             } else if (st == VISITING) {
                 throw new BuildException("Unexpected node in visiting state: "
-                    + root[i]);
+                    + roots[i]);
             }
         }
         final StringBuffer buf = new StringBuffer("Build sequence for target(s)");
 
-        for (int j = 0; j < root.length; j++) {
-            buf.append((j == 0) ? " `" : ", `").append(root[j]).append('\'');
+        for (int j = 0; j < roots.length; j++) {
+            buf.append((j == 0) ? " `" : ", `").append(roots[j]).append('\'');
         }
         buf.append(" is ").append(ret);
         log(buf.toString(), MSG_VERBOSE);
@@ -2019,6 +2019,8 @@ public class Project implements ResourceFactory {
     /**
      * Does the project know this reference?
      *
+     * @param key String
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean hasReference(final String key) {
@@ -2041,6 +2043,7 @@ public class Project implements ResourceFactory {
     /**
      * Look up a reference by its key (ID).
      *
+     * @param <T> desired type
      * @param key The key for the desired reference.
      *            Must not be <code>null</code>.
      *

http://git-wip-us.apache.org/repos/asf/ant/blob/67f29ce0/src/main/org/apache/tools/ant/ProjectComponent.java
----------------------------------------------------------------------
@@ -1803,13 +1803,13 @@ public class Project implements ResourceFactory {
      * Topologically sort a set of targets.
      *
-     * @param root <code>String[]</code> containing the names of the root targets.
-     *             The sort is created in such a way that the ordered sequence of
-     *             Targets is the minimum possible such sequence to the specified
-     *             root targets.
-     *             Must not be <code>null</code>.
+     * @param roots <code>String[]</code> containing the names of the root targets.
+     *              The sort is created in such a way that the ordered sequence of
+     *              Targets is the minimum possible such sequence to the specified
+     *              root targets.
+     *              Must not be <code>null</code>.
      * @param targetTable A map of names to targets (String to Target).